@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.5
+# Version   : 0.2.6
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -527,7 +527,7 @@ class AFM:
 
         i = 0
         
-        for curve_number in range(0, self.z_position_raw.shape[1]):
+        for curve_number in range(0, self.approach_raw.shape[1]):
 
             _approach = self.approach_raw[:,curve_number]
             _retract = self.retract_raw[:,curve_number]
